API
===

.. automodule:: numcertain
    :members:

    ``numcertain``
    --------------

.. data:: numcertain.__version__
    :type: str

    Version number as calculated by https://github.com/dls-controls/versiongit
